// ===========================================================================
// CONTENT  : ENUM TypeClassification
// AUTHOR   : M.Duchrow
// VERSION  : 1.3 - 21/02/2020
// HISTORY  :
//  07/01/2007  mdu  CREATED
//	13/01/2008	mdu		changed		-->	to be string based
//  10/10/2017  mdu   added     --> OSGI_BUNDLE
//  21/02/2020  mdu   added     --> SPRING_BOOT_JAR
//
// Copyright (c) 2007-2020, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.odem;

/**
 * Specifies the currently container types 
 *  
 * @author M.Duchrow
 * @version 1.3
 */
public enum ContainerClassification
{
	UNKNOWN("unknown"),
	NOT_FOUND("not-found"),
	JAVA_ARCHIVE("jar"),
	FILESYSTEM_FOLDER("dir"),
	WAR("war"),
	EAR("ear"),
	OSGI_BUNDLE("osgi-bundle"),
	SPRING_BOOT_JAR("spring-boot-jar"),
	COMPONENT("component");
	
	private final String externalName;
	
  /**
   * Returns the enum value with the given name. If none with that name can 
   * be found null will be returned.
   */
  public static ContainerClassification fromString(String valueName)
  {
    for (ContainerClassification classification : values())
    {
      if (classification.getExternalName().equals(valueName))
      {
        return classification;
      }
    }
    return null;
  } 

  private ContainerClassification(String str)
  {
    this.externalName = str;
  }  
  
  public String getExternalName()
  {
    return this.externalName;
  }
  
  /**
   * Returns the external string representation (which is not the same as the enum value name).
   */
  public String asString()
  {
    return this.getExternalName();
  }

  /**
   * Returns a debug string that should not be used in business logic.
   */
  @Override
  public String toString()
  {
    return String.format("%s('%s')", this.name(), this.getExternalName());
  }
} 
