// ===========================================================================
// CONTENT  : ENUM DependencyClassification
// AUTHOR   : M.Duchrow
// VERSION  : 1.2 - 13/01/2008
// HISTORY  :
//  07/01/2007  mdu  CREATED
//	09/02/2007	mdu		added		-->	CONTAINS, CONTAINED_IN, METHOD_RESULT
//	13/01/2008	mdu		changed	-->	to be string based
//
// Copyright (c) 2007-2008, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.odem;

/**
 * Specifies the currently supported types 
 *  
 * @author M.Duchrow
 * @version 1.2
 */
public enum DependencyClassification
{
	NEEDS("needs"),
	EXTENSION("extension"),
	IMPLEMENTATION("implementation"),
	ANNOTATION("annotation"),
	CLASS_REFLECT("class-reflect"),
	CLASS_CONST("class-const"),
	CONTAINS("contains"),
	CONTAINED_IN("contained-in"),
	FIELD_TYPE("field-type"),
	CONSTANT("constant"),
	METHOD_PARAM("method-param"),
	METHOD_RESULT("method-result"),
	LOCAL_FIELD_TYPE("local-field-type");
	
  private final String externalName;

  /**
   * Returns the enum value with the given name. If none with that name can 
   * be found null will be returned.
   */
  public static DependencyClassification fromString(String valueName)
  {
    for (DependencyClassification classification : values())
    {
      if (classification.getExternalName().equals(valueName))
      {
        return classification;
      }
    }
    return null;
  }

  private DependencyClassification(String str)
  {
    this.externalName = str;
  }
  
  public String getExternalName()
  {
    return this.externalName;
  }
  
  /**
   * Returns the external string representation (which is not the same as the enum value name).
   */
  public String asString()
  {
    return this.getExternalName();
  }

  /**
   * Returns a debug string that should not be used in business logic.
   */
  @Override
  public String toString()
  {
    return String.format("%s('%s')", this.name(), this.getExternalName());
  }
} 
