// ===========================================================================
// CONTENT  : INTERFACE IExplorationContext
// AUTHOR   : M.Duchrow
// VERSION  : 1.0 - 07/01/2007
// HISTORY  :
//  07/01/2007  mdu  CREATED
//
// Copyright (c) 2007, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.odem;

import java.util.Collection;

/**
 * Exploration of dependencies always must happen in a particular context.
 * That is, all elements that can be analyzed are included in this context.
 * Anything not in this context is out of scope for exploration. 
 *
 * @author M.Duchrow
 * @version 1.0
 */
public interface IExplorationContext extends IExplorationModelObject
{
  /**
   * Returns a text that describes the context.
   * 
   * @return A text or null
   */
  public String getDescription();

  /**
   * Returns all containers of this exploration context.
   * Theis method never returns null. If this context has no sub containers
   * an empty collection will be returned.
   * The result collection is always a copy. That means, manipulating the array 
   * does not affect the internal state/structure of this container, 
   */
  public Collection<IContainer> getContainers();

}