// ===========================================================================
// CONTENT  : INTERFACE INamespace
// AUTHOR   : M.Duchrow
// VERSION  : 1.0 - 07/01/2007
// HISTORY  :
//  07/01/2007  mdu  CREATED
//
// Copyright (c) 2007, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.odem;

import java.util.Collection;

/**
 * Represents a namespace an IType belongs to. That is, a Java package 
 * for example. 
 *
 * @author M.Duchrow
 * @version 1.0
 */
public interface INamespace extends IExplorableElement
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================
  /**
   * An empty array of INamespace elements that can be used as return value
   * in implementations whenever an empty array is needed.
   */
  public static final INamespace[] EMPTY_NAMESPACE_ARRAY = new INamespace[0];

  // =========================================================================
  // METHODS
  // =========================================================================
  /**
   * Returns all types in this namespace.
   * This method never returns null. If no type is contained in the
   * namespace an empty collection will be returned.
   */
  public Collection<IType> getTypes();

  /**
   * Implementation of the visitor pattern (GOF). 
   * It iterates (recursivly) over all contained INamespace objects and invokes 
   * the visitor's callback method using the namespaces as parameter.
   * 
   * @param visitor The implementor of the vistor interface to be called by this method
   * @return true if processing should be continued, otherwise false
   */
  public boolean acceptNamespaces(INamespacesVisitor visitor);

}